==> estateplat-common-1.2.4-20210721.090507-825-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxSgaCzrk.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:guting@gtmap.cn">guting</a>
 * @version 1.0, 2021/7/21
 * @description 省级信息共享-省公安厅-常驻人口信息
 */
@Table(name = "xxgx_sga_czrk")
public class XxgxSgaCzrk {
    @Id
    private String czrkid;//常驻人口信息id
    private String gmsfhm;//公民身份号码
    private String xm;//姓名
    private String xb;//性别
    private String mz;//民族
    private Date csrq;//出生日期
    private String hzxm;//户主姓名
    private String yhzgx;//与户主关系
    private String csdgjdq;//出生地国籍地区
    private String csdssqx;//出生地省市区县
    private String hjdz;//户籍地址
    private Date hjqfsj;//户籍签发时间
    private String hb;//户别
    private String ryzt;//人员状态
    private String proid;
    private String qlrid;
    private Date cxsj;

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public Date getCxsj() {
        return cxsj;
    }

    public void setCxsj(Date cxsj) {
        this.cxsj = cxsj;
    }

    public String getCzrkid() {
        return czrkid;
    }

    public void setCzrkid(String czrkid) {
        this.czrkid = czrkid;
    }

    public String getGmsfhm() {
        return gmsfhm;
    }

    public void setGmsfhm(String gmsfhm) {
        this.gmsfhm = gmsfhm;
    }

    public String getXm() {
        return xm;
    }

    public void setXm(String xm) {
        this.xm = xm;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getMz() {
        return mz;
    }

    public void setMz(String mz) {
        this.mz = mz;
    }

    public Date getCsrq() {
        return csrq;
    }

    public void setCsrq(Date csrq) {
        this.csrq = csrq;
    }

    public String getHzxm() {
        return hzxm;
    }

    public void setHzxm(String hzxm) {
        this.hzxm = hzxm;
    }

    public String getYhzgx() {
        return yhzgx;
    }

    public void setYhzgx(String yhzgx) {
        this.yhzgx = yhzgx;
    }

    public String getCsdssqx() {
        return csdssqx;
    }

    public void setCsdssqx(String csdssqx) {
        this.csdssqx = csdssqx;
    }

    public String getHjdz() {
        return hjdz;
    }

    public void setHjdz(String hjdz) {
        this.hjdz = hjdz;
    }

    public Date getHjqfsj() {
        return hjqfsj;
    }

    public void setHjqfsj(Date hjqfsj) {
        this.hjqfsj = hjqfsj;
    }

    public String getHb() {
        return hb;
    }

    public void setHb(String hb) {
        this.hb = hb;
    }

    public String getRyzt() {
        return ryzt;
    }

    public void setRyzt(String ryzt) {
        this.ryzt = ryzt;
    }

    public String getCsdgjdq() {
        return csdgjdq;
    }

    public void setCsdgjdq(String csdgjdq) {
        this.csdgjdq = csdgjdq;
    }
}

==> estateplat-common-1.2.4-20211028.005020-923-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxSgaCzrk.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:guting@gtmap.cn">guting</a>
 * @version 1.0, 2021/7/21
 * @description 省级信息共享-省公安厅-常驻人口信息
 */
@Table(name = "xxgx_sga_czrk")
public class XxgxSgaCzrk {
    @Id
    private String czrkid;//常驻人口信息id
    private String gmsfhm;//公民身份号码
    private String xm;//姓名
    private String xb;//性别
    private String mz;//民族
    private String csrq;//出生日期
    private String hzxm;//户主姓名
    private String yhzgx;//与户主关系
    private String csdgjdq;//出生地国籍地区
    private String csdssqx;//出生地省市区县
    private String hjdz;//户籍地址
    private Date hjqfsj;//户籍签发时间
    private String hb;//户别
    private String ryzt;//人员状态
    private String proid;
    private String qlrid;
    private Date cxsj;

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public Date getCxsj() {
        return cxsj;
    }

    public void setCxsj(Date cxsj) {
        this.cxsj = cxsj;
    }

    public String getCzrkid() {
        return czrkid;
    }

    public void setCzrkid(String czrkid) {
        this.czrkid = czrkid;
    }

    public String getGmsfhm() {
        return gmsfhm;
    }

    public void setGmsfhm(String gmsfhm) {
        this.gmsfhm = gmsfhm;
    }

    public String getXm() {
        return xm;
    }

    public void setXm(String xm) {
        this.xm = xm;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public String getMz() {
        return mz;
    }

    public void setMz(String mz) {
        this.mz = mz;
    }

    public String getCsrq() {
        return csrq;
    }

    public void setCsrq(String csrq) {
        this.csrq = csrq;
    }

    public String getHzxm() {
        return hzxm;
    }

    public void setHzxm(String hzxm) {
        this.hzxm = hzxm;
    }

    public String getYhzgx() {
        return yhzgx;
    }

    public void setYhzgx(String yhzgx) {
        this.yhzgx = yhzgx;
    }

    public String getCsdssqx() {
        return csdssqx;
    }

    public void setCsdssqx(String csdssqx) {
        this.csdssqx = csdssqx;
    }

    public String getHjdz() {
        return hjdz;
    }

    public void setHjdz(String hjdz) {
        this.hjdz = hjdz;
    }

    public Date getHjqfsj() {
        return hjqfsj;
    }

    public void setHjqfsj(Date hjqfsj) {
        this.hjqfsj = hjqfsj;
    }

    public String getHb() {
        return hb;
    }

    public void setHb(String hb) {
        this.hb = hb;
    }

    public String getRyzt() {
        return ryzt;
    }

    public void setRyzt(String ryzt) {
        this.ryzt = ryzt;
    }

    public String getCsdgjdq() {
        return csdgjdq;
    }

    public void setCsdgjdq(String csdgjdq) {
        this.csdgjdq = csdgjdq;
    }
}
